==> cryptoQuotes_1.2.1.tar.gz: cryptoQuotes/tests/testthat/test-availableTickers.R <==
testthat::test_that(
  desc = "availablePairs on Binance returns a vector of characters, with lenght > 1",
  code = {


    testthat::skip_on_ci()

    logicals <- c(TRUE, FALSE)

    for (lgl in logicals) {

      # 1) Load the available
      # tickers
      tickers <- availableTickers(
        source = 'binance',
        futures = lgl
      )

      # 2) Check wether its
      # a character vector
      testthat::expect_type(
        object = tickers,
        type = 'character'
      )

      # Check that the vector
      # is greater than one
      testthat::expect_gt(
        object = length(tickers),
        expected = 1

      )

    }


  }
)


testthat::test_that(
  desc = "availablePairs on Kraken returns a vector of characters, with lenght > 1",
  code = {


    testthat::skip_on_ci()

    logicals <- c(TRUE, FALSE)

    for (lgl in logicals) {

      # 1) Load the available
      # tickers
      tickers <- availableTickers(
        source = 'kraken',
        futures = lgl
      )

      # 2) Check wether its
      # a character vector
      testthat::expect_type(
        object = tickers,
        type = 'character'
      )

      # Check that the vector
      # is greater than one
      testthat::expect_gt(
        object = length(tickers),
        expected = 1

      )

    }


  }
)


testthat::test_that(
  desc = "availablePairs on Bitmart returns a vector of characters, with lenght > 1",
  code = {


    testthat::skip_on_ci()

    logicals <- c(TRUE, FALSE)

    for (lgl in logicals) {

      # 1) Load the available
      # tickers
      tickers <- availableTickers(
        source = 'bitmart',
        futures = lgl
      )

      # 2) Check wether its
      # a character vector
      testthat::expect_type(
        object = tickers,
        type = 'character'
      )

      # Check that the vector
      # is greater than one
      testthat::expect_gt(
        object = length(tickers),
        expected = 1

      )

    }


  }
)


testthat::test_that(
  desc = "availablePairs on Kucoin returns a vector of characters, with lenght > 1",
  code = {


    testthat::skip_on_ci()

    logicals <- c(TRUE, FALSE)

    for (lgl in logicals) {

      # 1) Load the available
      # tickers
      tickers <- availableTickers(
        source = 'kucoin',
        futures = lgl
      )

      # 2) Check wether its
      # a character vector
      testthat::expect_type(
        object = tickers,
        type = 'character'
      )

      # Check that the vector
      # is greater than one
      testthat::expect_gt(
        object = length(tickers),
        expected = 1

      )

    }


  }
)

==> cryptoQuotes_1.3.0.tar.gz: cryptoQuotes/tests/testthat/test-availableTickers.R <==
testthat::test_that(
  desc = "availablePairs on Binance returns a vector of characters, with lenght > 1",
  code = {

    # 0) skip if online;
    testthat::skip_if_offline()


    testthat::skip_on_ci()

    logicals <- c(TRUE, FALSE)

    for (lgl in logicals) {

      # 1) Load the available
      # tickers
      tickers <- available_tickers(
        source = 'binance',
        futures = lgl
      )

      # 2) Check wether its
      # a character vector
      testthat::expect_type(
        object = tickers,
        type = 'character'
      )

      # Check that the vector
      # is greater than one
      testthat::expect_gt(
        object = length(tickers),
        expected = 1

      )

    }


  }
)


testthat::test_that(
  desc = "availablePairs on Kraken returns a vector of characters, with lenght > 1",
  code = {

    # 0) skip if online;
    testthat::skip_if_offline()


    testthat::skip_on_ci()

    logicals <- c(TRUE, FALSE)

    for (lgl in logicals) {

      # 1) Load the available
      # tickers
      tickers <- available_tickers(
        source = 'kraken',
        futures = lgl
      )

      # 2) Check wether its
      # a character vector
      testthat::expect_type(
        object = tickers,
        type = 'character'
      )

      # Check that the vector
      # is greater than one
      testthat::expect_gt(
        object = length(tickers),
        expected = 1

      )

    }


  }
)


testthat::test_that(
  desc = "availablePairs on Bitmart returns a vector of characters, with lenght > 1",
  code = {

    # 0) skip if online;
    testthat::skip_if_offline()


    testthat::skip_on_ci()

    logicals <- c(TRUE, FALSE)

    for (lgl in logicals) {

      # 1) Load the available
      # tickers
      tickers <- available_tickers(
        source = 'bitmart',
        futures = lgl
      )

      # 2) Check wether its
      # a character vector
      testthat::expect_type(
        object = tickers,
        type = 'character'
      )

      # Check that the vector
      # is greater than one
      testthat::expect_gt(
        object = length(tickers),
        expected = 1

      )

    }


  }
)


testthat::test_that(
  desc = "availablePairs on Kucoin returns a vector of characters, with lenght > 1",
  code = {

    # 0) skip if online;
    testthat::skip_if_offline()


    testthat::skip_on_ci()

    logicals <- c(TRUE, FALSE)

    for (lgl in logicals) {

      # 1) Load the available
      # tickers
      tickers <- available_tickers(
        source = 'kucoin',
        futures = lgl
      )

      # 2) Check wether its
      # a character vector
      testthat::expect_type(
        object = tickers,
        type = 'character'
      )

      # Check that the vector
      # is greater than one
      testthat::expect_gt(
        object = length(tickers),
        expected = 1

      )

    }


  }
)
